@@ -22,32 +22,32 @@ print "  ፈተና  ፮፦ ዓለምፀሐይ contains /[#ለ-መ#]/\n"
 print "  ፈተና  ፯፦ ዓለምፀሐይ contains /[#ለ-መ#]/\n"             if ( $ፈተና =~ /[#ለመ#]/ );
 
 print "Form Range Operator Tests...\n";
-print "  ፈተና  ፰፦ ዓለምፀሐይ contains መ{%4-7}\n"               if ( $ፈተና =~ /መ{%4-7}/ );
-print "  ፈተና  ፱፦ ዓለምፀሐይ contains ፀ{%1,3-5,7}\n"           if ( $ፈተና =~ /ፀ{%1,3-5,7}/ );
+print "  ፈተና  ፰፦ ዓለምፀሐይ contains መ{#4-7#}\n"               if ( $ፈተና =~ /መ{#4-7#}/ );
+print "  ፈተና  ፱፦ ዓለምፀሐይ contains ፀ{#1,3-5,7#}\n"           if ( $ፈተና =~ /ፀ{#1,3-5,7#}/ );
 
-print "  ፈተና  ፲፦ ዓለምፀሐይ does not contain [ጸ]{%3}\n"       if ( $ፈተና !~ /[ጸ]{%3}/ );
-print "  ፈተና ፲፩፦ ዓለምፀሐይ does not contain [ጸ]{%11}\n"      if ( $ፈተና !~ /[ጸ]{%11}/ );
-print "  ፈተና ፲፪፦ ዓለምፀሐይ does not contain [ጸ]{%3-5}\n"     if ( $ፈተና !~ /[ጸ]{%3-5}/ );
-print "  ፈተና ፲፫፦ ዓለምፀሐይ does not contain [ጸ]{%3,5,7}\n"   if ( $ፈተና !~ /[ጸ]{%3-5,7}/ );
-print "  ፈተና ፲፬፦ ዓለምፀሐይ does not contain [ጸ]{%3,5}\n"     if ( $ፈተና !~ /[ጸ]{%3,5}/ );
+print "  ፈተና  ፲፦ ዓለምፀሐይ does not contain [ጸ]{#3#}\n"       if ( $ፈተና !~ /[ጸ]{#3#}/ );
+print "  ፈተና ፲፩፦ ዓለምፀሐይ does not contain [ጸ]{#11#}\n"      if ( $ፈተና !~ /[ጸ]{#11#}/ );
+print "  ፈተና ፲፪፦ ዓለምፀሐይ does not contain [ጸ]{#3-5#}\n"     if ( $ፈተና !~ /[ጸ]{#3-5#}/ );
+print "  ፈተና ፲፫፦ ዓለምፀሐይ does not contain [ጸ]{#3,5,7#}\n"   if ( $ፈተና !~ /[ጸ]{#3-5,7#}/ );
+print "  ፈተና ፲፬፦ ዓለምፀሐይ does not contain [ጸ]{#3,5#}\n"     if ( $ፈተና !~ /[ጸ]{#3,5#}/ );
 
-print "  ፈተና ፲፭፦ ዓለምፀሐይ does not contain [ሐጸ]{%4}\n"      if ( $ፈተና !~ /[ሐጸ]{%4}/ );
-print "  ፈተና ፲፮፦ ዓለምፀሐይ does not contain [ሐጸ]{%3,5}\n"    if ( $ፈተና !~ /[ሐጸ]{%3,5}/ );
+print "  ፈተና ፲፭፦ ዓለምፀሐይ does not contain [ሐጸ]{#4#}\n"      if ( $ፈተና !~ /[ሐጸ]{#4#}/ );
+print "  ፈተና ፲፮፦ ዓለምፀሐይ does not contain [ሐጸ]{#3,5#}\n"    if ( $ፈተና !~ /[ሐጸ]{#3,5#}/ );
 
-print "  ፈተና ፲፯፦ ዓለምፀሐይ contains [ለ-መ]{%6}\n"             if ( $ፈተና =~ /[ለ-መ]{%6}/ );
-print "  ፈተና ፲፰፦ ዓለምፀሐይ does not contain /[ለ-መ]{%3,5}/\n" if ( $ፈተና !~ /[ለ-መ]{%3,5}/ );
-print "  ፈተና ፲፱፦ ዓለምፀሐይ contains [ለ-መ]{%3,5-7}\n"         if ( $ፈተና =~ /[ለ-መ]{%3,5-7}/ );
+print "  ፈተና ፲፯፦ ዓለምፀሐይ contains [ለ-መ]{#6#}\n"             if ( $ፈተና =~ /[ለ-መ]{#6#}/ );
+print "  ፈተና ፲፰፦ ዓለምፀሐይ does not contain /[ለ-መ]{#3,5#}/\n" if ( $ፈተና !~ /[ለ-መ]{#3,5#}/ );
+print "  ፈተና ፲፱፦ ዓለምፀሐይ contains [ለ-መ]{#3,5-7#}\n"         if ( $ፈተና =~ /[ለ-መ]{#3,5-7#}/ );
 
-print "  ፈተና  ፳፦ ዓለምፀሐይ does not contain /[ጸለ-መ]{%4}/\n"  if ( $ፈተና !~ /[ጸለ-መ]{%4}/ );
-print "  ፈተና ፳፩፦ ዓለምፀሐይ matches /[ጸለ-መ]{%3,5-7}/\n"       if ( $ፈተና =~ /[ጸለ-መ]{%3,5-7}/ );
+print "  ፈተና  ፳፦ ዓለምፀሐይ does not contain /[ጸለ-መ]{#4#}/\n"  if ( $ፈተና !~ /[ጸለ-መ]{#4#}/ );
+print "  ፈተና ፳፩፦ ዓለምፀሐይ matches /[ጸለ-መ]{#3,5-7#}/\n"       if ( $ፈተና =~ /[ጸለ-መ]{#3,5-7#}/ );
 
 #
 # negation:
 #
 print "Negation Tests...\n";
-print "  ፈተና ፳፪፦ ዓለምፀሐይ matches [ሐጸ]{^%4}\n"              if ( $ፈተና =~ /[ሐጸ]{^%4}/ );
-print "  ፈተና ፳፫፦ ዓለምፀሐይ matches [^ሐጸ]{%4}\n"              if ( $ፈተና =~ /[^ሐጸ]{%4}/ );
-print "  ፈተና ፳፬፦ ዓለምፀሐይ matches [^ሐጸ]{^%4}\n"             if ( $ፈተና =~ /[^ሐጸ]{^%4}/ );  # double negative remains negative (as per amharic grammar)
+print "  ፈተና ፳፪፦ ዓለምፀሐይ matches [ሐጸ]{^#4#}\n"              if ( $ፈተና =~ /[ሐጸ]{^#4#}/ );
+print "  ፈተና ፳፫፦ ዓለምፀሐይ matches [^ሐጸ]{#4#}\n"              if ( $ፈተና =~ /[^ሐጸ]{#4#}/ );
+print "  ፈተና ፳፬፦ ዓለምፀሐይ matches [^ሐጸ]{^#4#}\n"             if ( $ፈተና =~ /[^ሐጸ]{^#4#}/ );  # double negative remains negative (as per amharic grammar)
 
 #
 # Ethiopic Class Tests
